@@ -9,7 +9,7 @@ from enum import Enum
 from pygqlc import GraphQLClient
 from singleton_decorator import singleton
 from .Notifications import NotificationBehaviour
-from .Logging import log, LogLevel
+from .Logging import log, LogLevel, LogStyle
 from . import uploaders
 from . import queries
 from . import mutations
@@ -61,6 +61,7 @@ class ValiotWorker():
     self.context = None
     self.unsubJobCreated = None
     # logging attributes
+    self.loggingStyle = LogStyle.PREFIX_FIRST_LINE
     self.stopLogging = False
     self.loggingProcess = None
     self.log = None
@@ -76,6 +77,9 @@ class ValiotWorker():
   
   def setPollingMode(self, mode):
     self.pollingMode = mode
+  
+  def setLoggingStyle(self, style):
+    self.loggingStyle = style
 
   def job(
     self,
@@ -535,18 +539,27 @@ class ValiotWorker():
     job : int, optional
       ID for the job sending this message, by default 0
     """
+    job_zero_padding = len(str(__.get(self.worker, 'jobs.0.id')))
     W = str(self.worker["id"]).zfill(2) # no need to pass as argument, will always be the same
     Q = str(__.get(queue, 'id', 0)).zfill(3)
-    J = str(__.get(job, 'id', 0)).zfill(7)
+    J = str(__.get(job, 'id', 0)).zfill(job_zero_padding)
     log_queue_key = __.get(queue, 'name', 'main')
     log_queue = self.logQueues[log_queue_key]
-    def sendLogToQueue(level, message):
-      D = getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
-      msgs = message.split('\n')
-      for msg in msgs:
+    if self.loggingStyle == LogStyle.PREFIX_ALL_LINES:
+      def sendLogToQueue(level, message):
+        D = getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
+        msgs = message.split('\n')
+        for msg in msgs:
+          log_queue.put({
+            'level': level,
+            'content': f'[D={D}/W={W}/Q={Q}/J={J}] - {msg}'
+          })
+    else:
+      def sendLogToQueue(level, message):
+        D = getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
         log_queue.put({
-          'level': level,
-          'content': f'[D={D}/W={W}/Q={Q}/J={J}] - {msg}'
+            'level': level,
+            'content': f'[D={D}/W={W}/Q={Q}/J={J}] - {message}'
         })
     return sendLogToQueue
 
